/*
 * $Id$
 *
 * [ Description ]
 * 
 */

#include "Behavioural/Generic/Queue/include/Parameters.h"
#include "Behavioural/include/XML.h"
using namespace std;

namespace morpheo                    {
namespace behavioural {
namespace generic {
namespace queue {


#undef  FUNCTION
#define FUNCTION "Queue::print"
  string Parameters::print (uint32_t depth)
  {
    log_printf(FUNC,Queue,FUNCTION,"Begin");

    XML xml ("queue");

    xml.balise_open("queue");
    xml.singleton_begin("size_queue"); xml.attribut("value",toString(_size_queue)); xml.singleton_end();
    xml.singleton_begin("size_data "); xml.attribut("value",toString(_size_data )); xml.singleton_end();
    xml.balise_close();

    log_printf(FUNC,Queue,FUNCTION,"End");
    
    return xml.get_body(depth);
  };

#undef  FUNCTION
#define FUNCTION "Queue::operator<<"
  ostream& operator<< (ostream& output_stream ,
		       morpheo::behavioural::generic::queue::Parameters & x)
  {
    log_printf(FUNC,Queue,FUNCTION,"Begin");

    output_stream << x.print(0);
    
    log_printf(FUNC,Queue,FUNCTION,"End");

    return output_stream;
  };

}; // end namespace queue
}; // end namespace generic

}; // end namespace behavioural
}; // end namespace morpheo              
